@@ -193,7 +193,7 @@ class JIRA(object):
             self.session()  # This will raise an Exception if you are not allowed to login. It's better to fail faster than later.
         # We need version in order to know what API calls are available or not
         self._version = tuple(self.server_info()['versionNumbers'])
-		
+
     def _check_for_html_error(self, content):
         # TODO: Make it return errors when content is a webpage with errors
         # JIRA has the bad habbit of returning errors in pages with 200 and embedding the error in a huge webpage.
@@ -952,7 +952,7 @@ class JIRA(object):
                               }
             data['updateAuthor'] = data['author']
         # TODO: report bug to Atlassian: author and updateAuthor parameters are ignored.
-        url = self._get_url('issue/{}/worklog'.format(issue))
+        url = self._get_url('issue/{0}/worklog'.format(issue))
         r = self._session.post(url, params=params, headers={'content-type': 'application/json'}, data=json.dumps(data))
         raise_on_error(r)
 
@@ -1777,7 +1777,7 @@ class JIRA(object):
         }
 
         r = self._session.post(url, headers=self._options['headers'], data=payload)
-        open("/tmp/jira_email_user_%s.html" % user, "w").write(r.content)
+        open("/tmp/jira_email_user_%s.html" % user, "w").write(r.text)
         # return False
 
         raise_on_error(r)
@@ -1817,21 +1817,21 @@ class JIRA(object):
 
         raise_on_error(r)
 
-        if re.compile("XSRF Security Token Missing").search(r.content):
+        if re.compile("XSRF Security Token Missing").search(r.text):
             logging.fatal("Reconfigure JIRA and disable XSRF in order to be able call this. See https://developer.atlassian.com/display/JIRADEV/Form+Token+Handling")
             return False
 
-        open("/tmp/jira_rename_user_%s_to%s.html" % (old_user, new_user), "w").write(r.content)
+        open("/tmp/jira_rename_user_%s_to%s.html" % (old_user, new_user), "w").write(r.text)
 
         msg = r.status_code
-        m = re.search("<span class=\"errMsg\">(.*)<\/span>", r.content)
+        m = re.search("<span class=\"errMsg\">(.*)<\/span>", r.text)
         if m:
             msg = m.group(1)
             logging.error(msg)
             return False
             # <span class="errMsg">Target user ID must exist already for a merge</span>
         p = re.compile("type=\"hidden\" name=\"cannedScriptArgs_Hidden_output\" value=\"(.*?)\"\/>", re.MULTILINE | re.DOTALL)
-        m = p.search(r.content)
+        m = p.search(r.text)
         if m:
             h = HTMLParser.HTMLParser()
             msg = h.unescape(m.group(1))
@@ -1867,7 +1867,7 @@ class JIRA(object):
             logging.error(r.status_code)
 
         # raise_on_error(r)
-        open("/tmp/jira_delete_user_%s_%s.html" % (r.status_code, username), "w").write(r.content)
+        open("/tmp/jira_delete_user_%s_%s.html" % (r.status_code, username), "w").write(r.text)
 
     def reindex(self, force=False, background=True):
         """
@@ -1893,17 +1893,17 @@ class JIRA(object):
             return 503
         # raise_on_error(r)
 
-        if not r.content.find("To perform the re-index now, please go to the") and force is False:
+        if not r.text.find("To perform the re-index now, please go to the") and force is False:
             return True
 
-        if r.content.find('All issues are being re-indexed'):
+        if r.text.find('All issues are being re-indexed'):
             logging.warning("JIRA re-indexing is already running.")
             return True  # still reindexing is considered still a success
 
-        if r.content.find('To perform the re-index now, please go to the') or force:
+        if r.text.find('To perform the re-index now, please go to the') or force:
             r = self._session.post(url, headers=self._options['headers'], params={"indexingStrategy": indexingStrategy, "reindex": "Re-Index"})
             # raise_on_error(r)
-            if r.content.find('All issues are being re-indexed') != -1:
+            if r.text.find('All issues are being re-indexed') != -1:
                 return True
             else:
                 logging.error("Failed to reindex jira, probably a bug.")
@@ -1960,7 +1960,7 @@ class JIRA(object):
         payload = {'pid': pid, 'Delete': 'Delete', 'confirm': 'true'}
         r = self._session.post(url, headers=self._options['headers'], data=payload)
         if r.status_code == 200:
-            return self._check_for_html_error(r.content.decode('utf8'))
+            return self._check_for_html_error(r.text)
         else:
             logging.warning('Got %s response from calling delete_project.' % r.status_code)
             return r.status_code
@@ -1997,11 +1997,11 @@ class JIRA(object):
         if r.status_code == 200:
             raise_on_error(r)
             r_json = json.loads(r.text)
-            content = r.content.decode('utf8')
+            content = r.text
             return r_json
 
         f = tempfile.NamedTemporaryFile(suffix='.html', prefix='python-jira-error-create-project-', delete=False)
-        f.write(r.content)
+        f.write(r.text)
         if self.logging:
             logging.error("Unexpected result while running create project. Server response saved in %s for further investigation [HTTP response=%s]." % (f.name, r.status_code))
         return False
@@ -2018,7 +2018,7 @@ class JIRA(object):
         r = self._session.post(url, headers=self._options['headers'], data=payload)
 
         if r.status_code == 200:
-            content = r.content.decode('utf8')
+            content = r.text
             if content.find('class="error">'):
                 m = re.search('class="error">(.*)</div>', content)
                 if m:
@@ -2045,7 +2045,7 @@ class JIRA(object):
             'join': 'submit'}
         r = self._session.post(url, headers=self._options['headers'], data=payload)
         if r.status_code == 200:
-            content = r.content.decode('utf8')
+            content = r.text
             if content.find('class="error">') != -1:
                 m = re.search('class="error">(.*)</div>', content)
                 if m:
